translate.filters.checks.StandardChecker

Package translate :: Package filters :: Module checks :: Class StandardChecker |
[hide private]
[frames] | no frames]

# Class StandardChecker

source code

The basic test suite for source -> target translations.

Instance Methods | [hide private]
untranslated(self, str1, str2) checks whether a string has been translated at all | source code
unchanged(self, str1, str2) checks whether a translation is basically identical to the original string | source code
blank(self, str1, str2) checks whether a translation only contains spaces | source code
short(self, str1, str2) checks whether a translation is much shorter than the original string | source code
long(self, str1, str2) checks whether a translation is much longer than the original string | source code
escapes(self, str1, str2) checks whether escaping is consistent between the two strings | source code
newlines(self, str1, str2) checks whether newlines are consistent between the two strings | source code
tabs(self, str1, str2) checks whether tabs are consistent between the two strings | source code
singlequoting(self, str1, str2) checks whether singlequoting is consistent between the two strings | source code
doublequoting(self, str1, str2) checks whether doublequoting is consistent between the two strings | source code
doublespacing(self, str1, str2) checks for bad double-spaces by comparing to original | source code
puncspacing(self, str1, str2) checks for bad spacing after punctuation | source code
printf(self, str1, str2) checks whether printf format strings match | source code
accelerators(self, str1, str2) checks whether accelerators are consistent between the two strings | source code
variables(self, str1, str2) checks whether variables of various forms are consistent between the two strings | source code
functions(self, str1, str2) checks that function names are not translated | source code
emails(self, str1, str2) checks that emails are not translated | source code
urls(self, str1, str2) checks that URLs are not translated | source code
numbers(self, str1, str2) checks whether numbers of various forms are consistent between the two strings | source code
startwhitespace(self, str1, str2) checks whether whitespace at the beginning of the strings matches | source code
endwhitespace(self, str1, str2) checks whether whitespace at the end of the strings matches | source code
startpunc(self, str1, str2) checks whether punctuation at the beginning of the strings match | source code
endpunc(self, str1, str2) checks whether punctuation at the end of the strings match | source code
purepunc(self, str1, str2) checks that strings that are purely punctuation are not changed | source code
brackets(self, str1, str2) checks that the number of brackets in both strings match | source code
sentencecount(self, str1, str2) checks that the number of sentences in both strings match | source code
options(self, str1, str2) checks that options are not translated | source code
startcaps(self, str1, str2) checks that the message starts with the correct capitalisation | source code
simplecaps(self, str1, str2) checks the capitalisation of two strings isn't wildly different | source code
acronyms(self, str1, str2) checks that acronyms that appear are unchanged | source code
doublewords(self, str1, str2) checks for repeated words in the translation | source code
notranslatewords(self, str1, str2) checks that words configured as untranslatable appear in the translation too | source code
musttranslatewords(self, str1, str2) checks that words configured as definitely translatable don't appear in the translation | source code
validchars(self, str1, str2) checks that only characters specified as valid appear in the translation | source code
filepaths(self, str1, str2) checks that file paths have not been translated | source code
xmltags(self, str1, str2) checks that XML/HTML tags have not been translated | source code
kdecomments(self, str1, str2) checks to ensure that no KDE style comments appear in the translation | source code
compendiumconflicts(self, str1, str2) checks for Gettext compendium conflicts (#-#-#-#-#) | source code
simpleplurals(self, str1, str2) checks for English style plural(s) for you to review | source code
spellcheck(self, str1, str2) checks words that don't pass a spell check | source code
credits(self, str1, str2) checks for messages containing translation credits instead of normal translations. | source code
Inherited from `TranslationChecker`: `__init__`, `run_filters`, `run_test` Inherited from `UnitChecker`: `filteraccelerators`, `filteraccelerators_by_list`, `filtervariables`, `filterwordswithpunctuation`, `filterxml`, `getfilters`, `removevariables`, `setconfig`, `setsuggestionstore` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| preconditions = `{"untranslated":("simplecaps", "variables", "s`...``

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### preconditions Value:
      {"untranslated":("simplecaps", "variables", "startcaps", "accelerators
      ", "brackets", "endpunc", "acronyms", "xmltags", "startpunc", "endwhit
      espace", "startwhitespace", "escapes", "doublequoting", "singlequoting
      ", "filepaths", "purepunc", "doublespacing", "sentencecount", "numbers
      ", "isfuzzy", "isreview", "notranslatewords", "musttranslatewords", "e
      mails", "simpleplurals", "urls", "printf", "tabs", "newlines", "functi
      ons", "options", "blank", "nplurals", "gconf"), "blank":("simplecaps",
       "variables", "startcaps", "accelerators", "brackets", "endpunc", "acr
      ...